<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Defines the editing form for the shortanswer question type.
 *
 * @package    qtype
 * @subpackage abstraktne
 * @copyright  2013 Lukas Malik
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


defined('MOODLE_INTERNAL') || die();


/**
 * Short answer question editing form definition.
 *
 * @copyright  2013 Lukas Malik
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class qtype_abstraktne_edit_form extends question_edit_form {
    
    
    
    /**
     * Definicia formularov
     */
    protected function definition_inner($mform) {
        global $PAGE;
        global $CFG;
        $PAGE->requires->js("/question/type/abstraktne/scripts/xmlreader.js");
        $PAGE->requires->css("/question/type/abstraktne/scripts/popup.css");
        $radioarray = array();
        $radioarray[] =& $mform->createElement('radio', 'mod_otazky', '', get_string('all_lines', 'qtype_abstraktne'), 0);
        $radioarray[] =& $mform->createElement('radio', 'mod_otazky', '', get_string('add_lines', 'qtype_abstraktne'), 1);
        $mform->addGroup($radioarray, 'radioar', get_string('mod_otazky', 'qtype_abstraktne'), array(' '), false);
        $mform->setDefault('mod_otazky', 0);
        
        $mform->addElement('textarea', 'formatovana_odpoved', get_string("formatovana_odpoved", "qtype_abstraktne"), 'wrap="virtual" rows="5" cols="50"');     
        $mform->addElement('header', 'povinne_nastavenia', get_string('povinne_nastavenia', 'qtype_abstraktne'));	
        $mform->addElement('advcheckbox', 'typ_vyhodnocovania', get_string('typ_vyhodnocovania', 'qtype_abstraktne'), '', array('group' => 1), array(0, 1));
                     
       // $mform->addElement('html', '<script type="text/javascript">var pop = new myPop("'.$CFG->wwwroot.'/question/type/abstraktne/pics");alert("asd");</script>');
        
        $mform->addElement('html','<div><input type=button value=Editor onclick="pop.popOut(document.getElementById(\'id_hod_data\').value,\''.$CFG->wwwroot.'/question/type/abstraktne/pics\');"></div>');
        $mform->addElement('textarea', 'hod_data', get_string("hod_data", "qtype_abstraktne"), 'wrap="virtual" rows="10" cols="50"');
        
       // $mform->addHelpButton('hod_data', array('hod_data', get_string('hod_data', 'qtype_abstraktne'), 'qtype_abstraktne'));     
        //$mform->addHelpButton('formatovana_odpoved', array('formatovana_odpoved', get_string('formatovana_odpoved','qtype_abstraktne'), 'qtype_abstraktne'));
        
        $mform->addRule('hod_data', null, 'required', null, 'client');
        $mform->addRule('radioar', null, 'required', null, 'client');
        $this->add_interactive_settings();
    }
    
    /**
     * Spracovanie otazky
     */
     
    protected function data_preprocessing($question) {
        $question = parent::data_preprocessing($question);
        $question = $this->data_preprocessing_answers($question);
        $question = $this->data_preprocessing_hints($question);

        return $question;
    }
    
    /**
     * Validacia formularov pred ulozenim
     */
    
    public function validation($data, $files) {
        global $CFG;
        $errors = parent::validation($data,$files);
        $errors = array();
        $dtd = $this->loadDTD();	
        $hod_data =$dtd.stripslashes($data['hod_data']);
        $dom = new DOMDocument;
        @$dom->loadXML($hod_data);
        
        if (@!$dom->validate())
        {  
            $errors['hod_data'] = get_string("bad_valid", "qtype_abstraktne");
        }
        
        if ($data['mod_otazky'] == 1)
        {
            $odp_for = $data['formatovana_odpoved'];
            $a = substr_count($odp_for,"<answer>");
            $b = substr_count($odp_for,"</answer>");
            if ($a != $b || $a == 0)
            {
                $errors['formatovana_odpoved'] = get_string("bad_format", "qtype_abstraktne");
            }
        }                  
        return $errors;
    }
    
    /**
     * Vracia nazov typu otazky
     */
    
    public function qtype() {
        return 'abstraktne';
    }
    
    /**
     * Nacita DTD subor do retazca
     */
    private function loadDTD()
    {
        global $CFG;
        $file = $CFG->wwwroot."/question/type/abstraktne/format.dtd";
        return file_get_contents($file);
    }
}
