<?php

/**
 * Abstraktne question definition class.
 *
 * @package    qtype
 * @subpackage abstraktne
 * @copyright  2013 Lukas Malik
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


defined('MOODLE_INTERNAL') || die();
require_once "scripts/call_wsEvaluate.php";

/**
 * Represents a abstraktne question.
 *
 * @copyright  2013 Lukas Malik
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class qtype_abstraktne_question extends question_graded_automatically {
    
    
    /**
     * Nacita polia pre ocakavane data
     */
    
    public function get_expected_data() {
        $return = array();
        for ($i = 0; $i < $this->getCount(); $i++) {
            $return['answer_'.$i] = PARAM_RAW_TRIMMED;
        }
//        echo '<pre>'; print_r($return); echo '</pre>';
        return $return;

    }
    
    /**
     * Zosumarizuje odpovede
     */
    public function summarise_response(array $response) {
        $return = array();
        for ($i = 0; $i < $this->getCount(); $i++) {
            $return[] = 'Input '.$i.' = ' . $response['answer_'.$i];
        }
        return implode(' ; ', $return);
    }
    /**
     * Zisti pocet ocakavanych odpovedi
     */
    
    function getCount()
    {
        if ($this->mod_otazky == 1)
        {
            preg_match_all("/<answer>(.*?)<\/answer>/is",$this->formatovana_odpoved,$matches);
            return $count = count($matches[0]);
        }
        else
        {
            return 1;
        }
    }
    
    /**
     * Zisti ci je dopoved kompletna
     */
    
    public function is_complete_response(array $response) {
        
        for ($i = 0; $i < $this->getCount(); $i++) {
            if (!array_key_exists('answer_'.$i, $response) || (!$response['answer_'.$i] && $response['answer_'.$i] !== '0')) {
                return false;
            }
        }
        return true;
    }

    
    public function get_validation_error(array $response) {
        
        $resp = $response['answer'];
        if ($this->is_gradable_response($resp[0])) {
            return '';
        }
        return get_string('pleaseenterananswer', 'qtype_shortanswer');
    }

    public function is_same_response(array $prevresponse, array $newresponse) {
       /* foreach($this->get_parameters() as $param) {
            if (!question_utils::arrays_same_at_key_missing_is_blank($prevresponse, $newresponse, 'answer_'.$param)) {
                return false;
            }
        }
        */
        return false;
    }

    public function get_answers() {
        return $this->answers;
    }
    
    /**
     * Vyhodnoti odpoved
     */
    
    public function grade_response(array $response) {
       // print_r($response);
        $call_webservice = new Call_wsEvaluate($response['answer_0'], $this->hod_data, 0);
        $vysledok = $call_webservice->hodnota / 100;
        //break;
        return array($vysledok, question_state::graded_state_for_fraction($vysledok));

    }    



   

 

    public function get_correct_response() {
        
    // vrati spravnu odpoved, pre nas pripad je tato funkcia zbytocna
        
        return '';
    }

  

    public function check_file_access($qa, $options, $component, $filearea,
            $args, $forcedownload) {
        if ($component == 'question' && $filearea == 'answerfeedback') {
            $currentanswer = $qa->get_last_qt_var('answer');
            $answer = $this->get_matching_answer(array('answer' => $currentanswer));
            $answerid = reset($args); // itemid is answer id.
            return $options->feedback && $answer && $answerid == $answer->id;

        } else if ($component == 'question' && $filearea == 'hint') {
            return $this->check_hint_file_access($qa, $options, $args);

        } else {
            return parent::check_file_access($qa, $options, $component, $filearea,
                    $args, $forcedownload);
        }
    }
}
